@@ -1,6 +1,4 @@
-/*
- * -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*-
- */
+/* -*- mode: C; indent-tabs-mode: t; tab-width: 8; c-basic-offset: 2; -*- */
 
 /*
  * This file is part of Seed, the GObject Introspection<->Javascript bindings.
@@ -16,7 +14,7 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with Seed.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) Robert Carr 2008 <carrr@rpi.edu>
+ * Copyright (C) Robert Carr 2009 <carrr@rpi.edu>
  */
 
 #ifndef _SEED_CLOSURE_H_
@@ -49,25 +47,25 @@ extern JSClassRef seed_native_callback_class;
 
 SeedNativeClosure *seed_make_native_closure (JSContextRef ctx,
 					     GICallableInfo * info,
-					     GIArgInfo *arg_info,
+					     GIArgInfo * arg_info,
 					     JSValueRef function);
 GClosure *seed_closure_new (JSContextRef ctx,
 			    JSObjectRef function,
-			    JSObjectRef user_data,
-			    const gchar *description);
+			    JSObjectRef user_data, const gchar * description);
 
-JSObjectRef
-seed_closure_get_callable (GClosure *c);
+JSObjectRef seed_closure_get_callable (GClosure * c);
 
 JSValueRef
-seed_closure_invoke (GClosure *closure, JSValueRef *args, guint argc, JSValueRef *exception);
-JSValueRef
-seed_closure_invoke_with_context (JSContextRef ctx, GClosure *closure, JSValueRef *args, guint argc, JSValueRef *exception);
+seed_closure_invoke (GClosure * closure, JSValueRef * args, guint argc,
+		     JSValueRef * exception);
+JSValueRef seed_closure_invoke_with_context (JSContextRef ctx,
+					     GClosure * closure,
+					     JSValueRef * args, guint argc,
+					     JSValueRef * exception);
 
 void
-seed_closure_warn_exception (GClosure *c,
-			     JSContextRef ctx,
-			     JSValueRef exception);
+seed_closure_warn_exception (GClosure * c,
+			     JSContextRef ctx, JSValueRef exception);
 
 
 
