@@ -1,3 +1,5 @@
+/* -*- mode: C; indent-tabs-mode: t; tab-width: 8; c-basic-offset: 2; -*- */
+
 /*
  * This file is part of Seed, the GObject Introspection<->Javascript bindings.
  *
@@ -12,12 +14,11 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with Seed.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) Robert Carr 2008 <carrr@rpi.edu>
+ * Copyright (C) Robert Carr 2009 <carrr@rpi.edu>
  */
 
 #include "seed-private.h"
 #include <dlfcn.h>
-#include <string.h>
 
 JSClassRef gobject_class;
 JSClassRef gobject_method_class;
@@ -76,7 +77,7 @@ seed_make_wrapper_for_type (JSContextRef ctx, GType type)
   if (prototype)
     JSObjectSetPrototype (ctx, ret, prototype);
   else
-    g_assert_not_reached();
+    g_assert_not_reached ();
 
   return ret;
 }
@@ -103,7 +104,7 @@ seed_wrap_object (JSContextRef ctx, GObject * object)
   JSObjectSetPrivate (js_ref, object);
 
   g_object_set_qdata_full (object, js_ref_quark, (gpointer) js_ref,
-			  seed_gobject_destroyed);
+			   seed_gobject_destroyed);
 
   JSValueProtect (eng->context, js_ref);
   g_object_add_toggle_ref (object, seed_toggle_ref, (gpointer) js_ref);
@@ -120,6 +121,9 @@ seed_release_arg (GITransfer transfer,
 		  GITypeInfo * type_info, GITypeTag type_tag, GArgument * arg)
 {
   GType gtype;
+  GITypeInfo *param_type;
+  GIBaseInfo *interface_info;
+  GValue *gval;
 
   switch (type_tag)
     {
@@ -130,8 +134,6 @@ seed_release_arg (GITransfer transfer,
     case GI_TYPE_TAG_ARRAY:
       if (arg->v_pointer)
 	{
-	  GITypeInfo *param_type;
-
 	  param_type = g_type_info_get_param_type (type_info, 0);
 
 	  switch (g_type_info_get_tag (param_type))
@@ -160,8 +162,6 @@ seed_release_arg (GITransfer transfer,
       {
 	if (arg->v_pointer)
 	  {
-	    GIBaseInfo *interface_info;
-
 	    interface_info = g_type_info_get_interface (type_info);
 
 	    gtype =
@@ -181,7 +181,7 @@ seed_release_arg (GITransfer transfer,
 	      }
 	    else if (g_type_is_a (gtype, G_TYPE_VALUE))
 	      {
-		GValue *gval = (GValue *) arg->v_pointer;
+		gval = (GValue *) arg->v_pointer;
 		// Free/unref the GValue's contents.
 		g_value_unset (gval);
 		// Free the GValue.
@@ -220,8 +220,7 @@ seed_gi_release_arg (GITransfer transfer,
 
 gboolean
 seed_gi_release_in_arg (GITransfer transfer,
-			GITypeInfo * type_info,
-			GArgument * arg)
+			GITypeInfo * type_info, GArgument * arg)
 {
   GITypeTag type_tag;
 
@@ -256,15 +255,15 @@ seed_gi_make_jsarray (JSContextRef ctx,
 		      GITypeInfo * param_type, JSValueRef * exception)
 {
   GITypeTag element_type;
+  JSValueRef *elements;
+  guint length, i;
+  gchar **str_array = (gchar **) array;
   JSValueRef ret = JSValueMakeNull (ctx);
 
   element_type = g_type_info_get_tag (param_type);
 
   if (element_type == GI_TYPE_TAG_UTF8)
     {
-      JSValueRef *elements;
-      guint length, i;
-      gchar **str_array = (gchar **) array;
 
       length = g_strv_length (str_array);
       if (!length)
@@ -290,6 +289,8 @@ seed_gi_make_array (JSContextRef ctx,
 		    void **array_p, JSValueRef * exception)
 {
   GITypeTag element_type;
+  JSValueRef elem;
+  guint i;
 
   element_type = g_type_info_get_tag (param_type);
 
@@ -297,116 +298,102 @@ seed_gi_make_array (JSContextRef ctx,
     {
     case GI_TYPE_TAG_UTF8:
       {
-	char **result;
-	guint i;
-
-	result = g_new0 (char *, length + 1);
+	gchar **strresult = g_new0 (gchar *, length + 1);
 
 	for (i = 0; i < length; i++)
 	  {
-	    JSValueRef elem = JSObjectGetPropertyAtIndex (ctx,
-							  (JSObjectRef) array,
-							  i,
-							  exception);
-	    result[i] = seed_value_to_string (ctx, elem, exception);
+	    elem = JSObjectGetPropertyAtIndex (ctx,
+					       (JSObjectRef) array,
+					       i, exception);
+	    strresult[i] = seed_value_to_string (ctx, elem, exception);
 	  }
 
-	*array_p = result;
+	*array_p = strresult;
       }
       break;
     case GI_TYPE_TAG_GTYPE:
       {
-	GType *result;
-	guint i;
+	GType *typeresult;
 
-	result = g_new0 (GType, length + 1);
+	typeresult = g_new0 (GType, length + 1);
 
 	for (i = 0; i < length; i++)
 	  {
-	    JSValueRef elem = JSObjectGetPropertyAtIndex (ctx,
-							  (JSObjectRef) array,
-							  i,
-							  exception);
-	    result[i] = seed_value_to_int (ctx, elem, exception);
+	    elem = JSObjectGetPropertyAtIndex (ctx,
+					       (JSObjectRef) array,
+					       i, exception);
+	    typeresult[i] = seed_value_to_int (ctx, elem, exception);
 	  }
 
-	*array_p = result;
+	*array_p = typeresult;
       }
       break;
     case GI_TYPE_TAG_FLOAT:
       {
-	gfloat *result;
-	guint i;
+	gfloat *floatresult;
 
-	result = g_new0 (gfloat, length + 1);
+	floatresult = g_new0 (gfloat, length + 1);
 
 	for (i = 0; i < length; i++)
 	  {
-	    JSValueRef elem = JSObjectGetPropertyAtIndex (ctx,
-							  (JSObjectRef) array,
-							  i,
-							  exception);
-	    result[i] = seed_value_to_float (ctx, elem, exception);
+	    elem = JSObjectGetPropertyAtIndex (ctx,
+					       (JSObjectRef) array,
+					       i, exception);
+	    floatresult[i] = seed_value_to_float (ctx, elem, exception);
 	  }
 
-	*array_p = result;
+	*array_p = floatresult;
       }
       break;
     case GI_TYPE_TAG_DOUBLE:
       {
-	gdouble *result;
-	guint i;
+	gdouble *dblresult;
 
-	result = g_new0 (gdouble, length + 1);
+	dblresult = g_new0 (gdouble, length + 1);
 
 	for (i = 0; i < length; i++)
 	  {
-	    JSValueRef elem = JSObjectGetPropertyAtIndex (ctx,
-							  (JSObjectRef) array,
-							  i,
-							  exception);
-	    result[i] = seed_value_to_double (ctx, elem, exception);
+	    elem = JSObjectGetPropertyAtIndex (ctx,
+					       (JSObjectRef) array,
+					       i, exception);
+	    dblresult[i] = seed_value_to_double (ctx, elem, exception);
 	  }
 
-	*array_p = result;
+	*array_p = dblresult;
       }
       break;
     case GI_TYPE_TAG_INT:
       {
-	gint *result;
-	guint i;
+	gint *intresult;
 
-	result = g_new0 (gint, length + 1);
+	intresult = g_new0 (gint, length + 1);
 
 	for (i = 0; i < length; i++)
 	  {
-	    JSValueRef elem = JSObjectGetPropertyAtIndex (ctx,
-							  (JSObjectRef) array,
-							  i,
-							  exception);
-	    result[i] = seed_value_to_int (ctx, elem, exception);
+	    elem = JSObjectGetPropertyAtIndex (ctx,
+					       (JSObjectRef) array,
+					       i, exception);
+	    intresult[i] = seed_value_to_int (ctx, elem, exception);
 	  }
 
-	*array_p = result;
+	*array_p = intresult;
       }
       break;
     case GI_TYPE_TAG_UINT8:
       {
-	guint8 *result;
-	guint i;
+	guint8 *guint8result;
 
-	result = g_new0 (guint8, length + 1);
+	guint8result = g_new0 (guint8, length + 1);
 
 	for (i = 0; i < length; i++)
 	  {
-	    JSValueRef elem = JSObjectGetPropertyAtIndex (ctx,
-							  (JSObjectRef) array,
-							  i,
-							  exception);
-	    result[i] = seed_value_to_uchar (ctx, elem, exception);
+	    elem = JSObjectGetPropertyAtIndex (ctx,
+					       (JSObjectRef) array,
+					       i, exception);
+	    guint8result[i] = seed_value_to_uchar (ctx, elem, exception);
 	  }
 
-	*array_p = result;
+	*array_p = guint8result;
       }
       break;
     case GI_TYPE_TAG_INTERFACE:
@@ -422,24 +409,22 @@ seed_gi_make_array (JSContextRef ctx,
 						 interface);
 	    if (g_type_is_a (type, G_TYPE_VALUE))
 	      {
-		GValue *result;
-		guint i;
+		GValue *gvalresult;
 
 		// TODO:FIXME: Robb. Valgrind thinks there's a leak here,
 		//             at least while running Same Seed.
-		result = g_new0 (GValue, length + 1);
+		gvalresult = g_new0 (GValue, length + 1);
 
 		for (i = 0; i < length; i++)
 		  {
-		    JSValueRef elem = JSObjectGetPropertyAtIndex (ctx,
-								  (JSObjectRef) array,
-								  i,
-								  exception);
+		    elem = JSObjectGetPropertyAtIndex (ctx,
+						       (JSObjectRef) array,
+						       i, exception);
 		    seed_gvalue_from_seed_value (ctx, elem,
 						 (GType) 0,
-						 &result[i], exception);
+						 &gvalresult[i], exception);
 		  }
-		*array_p = result;
+		*array_p = gvalresult;
 
 		g_base_info_unref (interface);
 		break;
@@ -461,9 +446,8 @@ gboolean
 seed_gi_make_argument (JSContextRef ctx,
 		       JSValueRef value,
 		       GITypeInfo * type_info,
-		       GIArgInfo *arg_info,
-		       GArgument * arg,
-		       JSValueRef * exception)
+		       GIArgInfo * arg_info,
+		       GArgument * arg, JSValueRef * exception)
 {
   GITypeTag gi_tag = g_type_info_get_tag (type_info);
 
@@ -575,7 +559,9 @@ seed_gi_make_argument (JSContextRef ctx,
 		 interface_type == GI_INFO_TYPE_FLAGS)
 	  {
 	    arg->v_long = seed_value_to_long (ctx, value, exception);
-	    if (!(interface_type == GI_INFO_TYPE_FLAGS) && !seed_validate_enum ((GIEnumInfo *)interface, arg->v_long))
+	    if (!(interface_type == GI_INFO_TYPE_FLAGS)
+		&& !seed_validate_enum ((GIEnumInfo *) interface,
+					arg->v_long))
 	      {
 		seed_make_exception (ctx, exception, "EnumRange",
 				     "Enum value: %ld is out of range",
@@ -621,7 +607,8 @@ seed_gi_make_argument (JSContextRef ctx,
 		    if (JSObjectIsFunction (ctx, (JSObjectRef) value))
 		      {
 			arg->v_pointer =
-				seed_closure_new (ctx, (JSObjectRef) value, NULL, NULL);
+			  seed_closure_new (ctx, (JSObjectRef) value, NULL,
+					    NULL);
 		      }
 		  }
 		else
@@ -881,8 +868,9 @@ seed_gi_argument_make_js (JSContextRef ctx,
       {
 	GITypeInfo *list_type;
 	JSObjectRef ret;
+	JSValueRef ival;
 	GArgument larg;
-	gint i = 0;
+	guint i = 0;
 	GSList *list = arg->v_pointer;
 
 	ret = JSObjectMakeArray (ctx, 0, NULL, exception);
@@ -890,8 +878,6 @@ seed_gi_argument_make_js (JSContextRef ctx,
 
 	for (; list != NULL; list = list->next)
 	  {
-	    JSValueRef ival;
-
 	    larg.v_pointer = list->data;
 	    ival =
 	      (JSValueRef) seed_gi_argument_make_js (ctx, &larg,
@@ -1092,12 +1078,11 @@ seed_gvalue_from_seed_value (JSContextRef ctx,
 	if (type == 0 && JSValueIsObject (ctx, val))
 	  {
 	    // TODO: FIXME: Better array test like the cool one on reddit.
-	    guint length =
-	      seed_value_to_int (ctx,
-				 seed_object_get_property (ctx,
-							   (JSObjectRef) val,
-							   "length"),
-				 exception);
+	    guint length = seed_value_to_int (ctx,
+					      seed_object_get_property (ctx,
+									(JSObjectRef) val,
+									"length"),
+					      exception);
 
 	    if (length)
 	      {
@@ -1261,7 +1246,8 @@ seed_object_set_property (JSContextRef ctx, JSObjectRef object,
 
   if (value)
     {
-      JSObjectSetProperty (ctx, (JSObjectRef) object, jname, value, 0, &exception);
+      JSObjectSetProperty (ctx, (JSObjectRef) object, jname, value, 0,
+			   &exception);
     }
 
   JSStringRelease (jname);
@@ -1279,7 +1265,10 @@ seed_object_set_property (JSContextRef ctx, JSObjectRef object,
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %gboolean represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #gboolean. Keep in mind that this will
+ * not convert a JavaScript number type, only a boolean.
+ *
+ * Return value: The #gboolean represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1293,10 +1282,10 @@ seed_value_to_boolean (JSContextRef ctx,
 	{
 	  seed_make_exception (eng->context, exception, "ConversionError",
 			       "Can not convert Javascript value to boolean");
-	  return 0;
+	  return FALSE;
 	}
 
-      return 0;
+      return FALSE;
     }
 
   return JSValueToBoolean (ctx, val);
@@ -1309,7 +1298,9 @@ seed_value_to_boolean (JSContextRef ctx,
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #gboolean into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1327,7 +1318,9 @@ seed_value_from_boolean (JSContextRef ctx,
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %guint represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #guint.
+ *
+ * Return value: The #guint represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1355,7 +1348,9 @@ seed_value_to_uint (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #guint into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1372,7 +1367,9 @@ seed_value_from_uint (JSContextRef ctx, guint val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %gint represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #gint.
+ *
+ * Return value: The #gint represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1397,7 +1394,9 @@ seed_value_to_int (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #gint into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1414,7 +1413,9 @@ seed_value_from_int (JSContextRef ctx, gint val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %gchar represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #gchar.
+ *
+ * Return value: The #gchar represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1440,7 +1441,7 @@ seed_value_to_char (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
       return 0;
     }
 
-  return (char) cv;
+  return (gchar) cv;
 }
 
 /**
@@ -1450,7 +1451,9 @@ seed_value_to_char (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #gchar into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1467,7 +1470,9 @@ seed_value_from_char (JSContextRef ctx, gchar val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %guchar represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #guchar.
+ *
+ * Return value: The #guchar represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1503,7 +1508,9 @@ seed_value_to_uchar (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #guchar into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1520,7 +1527,9 @@ seed_value_from_uchar (JSContextRef ctx, guchar val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %gshort represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #gshort.
+ *
+ * Return value: The #gshort represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1545,7 +1554,9 @@ seed_value_to_short (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #gshort into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1562,12 +1573,15 @@ seed_value_from_short (JSContextRef ctx, gshort val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %gushort represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #gushort.
+ *
+ * Return value: The #gushort represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
 gushort
-seed_value_to_ushort (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
+seed_value_to_ushort (JSContextRef ctx, JSValueRef val,
+		      JSValueRef * exception)
 {
   if (!JSValueIsNumber (ctx, val) && !JSValueIsBoolean (ctx, val))
     {
@@ -1587,7 +1601,9 @@ seed_value_to_ushort (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #gushort into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1604,7 +1620,9 @@ seed_value_from_ushort (JSContextRef ctx, gushort val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %glong represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #glong.
+ *
+ * Return value: The #glong represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1629,7 +1647,9 @@ seed_value_to_long (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #glong into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1646,7 +1666,9 @@ seed_value_from_long (JSContextRef ctx, glong val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %gulong represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #gulong.
+ *
+ * Return value: The #gulong represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1672,7 +1694,9 @@ seed_value_to_ulong (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #gulong into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1689,7 +1713,9 @@ seed_value_from_ulong (JSContextRef ctx, gulong val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %gint64 represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #gint64.
+ *
+ * Return value: The #gint64 represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1715,7 +1741,9 @@ seed_value_to_int64 (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #gint64 into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1732,7 +1760,9 @@ seed_value_from_int64 (JSContextRef ctx, gint64 val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %guint64 represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #guint64.
+ *
+ * Return value: The #guint64 represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1760,7 +1790,9 @@ seed_value_to_uint64 (JSContextRef ctx,
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #guint64 into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1777,7 +1809,9 @@ seed_value_from_uint64 (JSContextRef ctx, guint64 val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %gfloat represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #gfloat.
+ *
+ * Return value: The #gfloat represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1802,7 +1836,9 @@ seed_value_to_float (JSContextRef ctx, JSValueRef val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #gfloat into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1819,7 +1855,9 @@ seed_value_from_float (JSContextRef ctx, gfloat val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %gdouble represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #gdouble.
+ *
+ * Return value: The #gdouble represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1845,7 +1883,9 @@ seed_value_to_double (JSContextRef ctx,
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #gdouble into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1862,7 +1902,20 @@ seed_value_from_double (JSContextRef ctx, gdouble val, JSValueRef * exception)
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: The %gchar* represented by @val, or %NULL if an exception
+ * Converts the given #SeedValue into a #gchar* string. Keep in mind that it's
+ * up to the caller to free the string.
+ *
+ * If the #SeedValue represents JavaScript's undefined value, this returns
+ * "[undefined]"; if it represents JavaScript's null value, this returns
+ * "[null]".
+ *
+ * If the #SeedValue is a number or a boolean, it is printed as a double, with 
+ * the printf format string "%.15g".
+ *
+ * If the #SeedValue is an object, the string returned is that obtained by
+ * calling .toString() on said object.
+ *
+ * Return value: The #gchar* represented by @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1896,11 +1949,14 @@ seed_value_to_string (JSContextRef ctx,
 	{
 	  func =
 	    seed_object_get_property (ctx, (JSObjectRef) val, "toString");
-	  str =
-	    JSObjectCallAsFunction (ctx, (JSObjectRef) func,
-				    (JSObjectRef) val, 0, NULL, NULL);
+	  if (!JSValueIsNull (ctx, func) &&
+	      JSValueIsObject (ctx, func) &&
+	      JSObjectIsFunction (ctx, (JSObjectRef) func))
+	    str =
+	      JSObjectCallAsFunction (ctx, (JSObjectRef) func,
+				      (JSObjectRef) val, 0, NULL, NULL);
 	}
-
+      
       jsstr = JSValueToStringCopy (ctx, val, NULL);
       length = JSStringGetMaximumUTF8CStringSize (jsstr);
       if (length > 0)
@@ -1922,7 +1978,9 @@ seed_value_to_string (JSContextRef ctx,
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
- * Return value: A %SeedValue which represents @val, or %NULL if an exception
+ * Converts the given #gchar* string into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
  *               is raised during the conversion.
  *
  */
@@ -1937,16 +1995,30 @@ seed_value_from_string (JSContextRef ctx,
   return valstr;
 }
 
+/**
+ * seed_value_from_binary_string:
+ * @ctx: A #SeedContext.
+ * @bytes: A string of bytes to represent as a string.
+ * @n_bytes: The number of bytes from @bytes to convert.
+ * @exception: A reference to a #SeedValue in which to store any exceptions.
+ *             Pass %NULL to ignore exceptions.
+ *
+ * Converts a string representation of the given binary string
+ * into a #SeedValue.
+ *
+ * Return value: A #SeedValue which represents @bytes as a string, or %NULL
+ *               if an exception is raised during the conversion.
+ *
+ */
 JSValueRef
 seed_value_from_binary_string (JSContextRef ctx,
-			       const gchar *bytes,
-			       gint n_bytes,
-			       JSValueRef *exception)
+			       const gchar * bytes,
+			       gint n_bytes, JSValueRef * exception)
 {
   JSValueRef ret;
 
-  gchar *nstr = g_alloca ((n_bytes +1)*sizeof(gchar));
-  strncpy (nstr, bytes, n_bytes);
+  gchar *nstr = g_alloca ((n_bytes + 1) * sizeof (gchar));
+  g_strlcpy (nstr, bytes, n_bytes);
   nstr[n_bytes] = '\0';
 
   ret = seed_value_from_string (ctx, nstr, exception);
@@ -1954,6 +2026,20 @@ seed_value_from_binary_string (JSContextRef ctx,
   return ret;
 }
 
+/**
+ * seed_value_to_filename:
+ * @ctx: A #SeedContext.
+ * @val: The #SeedValue to convert.
+ * @exception: A reference to a #SeedValue in which to store any exceptions.
+ *             Pass %NULL to ignore exceptions.
+ *
+ * Converts the given #SeedValue into a #gchar*, properly converting to the 
+ * character set used for filenames on the local machine.
+ *
+ * Return value: The #gchar* represented by @val, or %NULL if an exception
+ *               is raised during the conversion.
+ *
+ */
 gchar *
 seed_value_to_filename (JSContextRef ctx,
 			JSValueRef val, JSValueRef * exception)
@@ -1974,14 +2060,28 @@ seed_value_to_filename (JSContextRef ctx,
   return filename;
 }
 
+/**
+ * seed_value_from_filename:
+ * @ctx: A #SeedContext.
+ * @val: The #gchar* filename to represent.
+ * @exception: A reference to a #SeedValue in which to store any exceptions.
+ *             Pass %NULL to ignore exceptions.
+ *
+ * Converts the given #gchar* filename into a #SeedValue, respecting the 
+ * character set used for filenames on the local machine.
+ *
+ * Return value: A #SeedValue which represents @val, or %NULL if an exception
+ *               is raised during the conversion.
+ *
+ */
 JSValueRef
 seed_value_from_filename (JSContextRef ctx,
-			  const gchar * filename, JSValueRef * exception)
+			  const gchar * val, JSValueRef * exception)
 {
   GError *e = NULL;
   gchar *utf8;
 
-  utf8 = g_filename_to_utf8 (filename, -1, NULL, NULL, &e);
+  utf8 = g_filename_to_utf8 (val, -1, NULL, NULL, &e);
 
   if (e)
     {
@@ -1998,8 +2098,20 @@ seed_value_from_filename (JSContextRef ctx,
   return valstr;
 }
 
-
-
+/**
+ * seed_value_to_object:
+ * @ctx: A #SeedContext.
+ * @val: The #SeedValue to unwrap.
+ * @exception: A reference to a #SeedValue in which to store any exceptions.
+ *             Pass %NULL to ignore exceptions.
+ *
+ * Given a #SeedValue which is wrapping a #GObject, retrieve the wrapped
+ * #GObject.
+ *
+ * Return value: The #GObject wrapped within @val, or %NULL if an exception
+ *               is raised during the conversion.
+ *
+ */
 GObject *
 seed_value_to_object (JSContextRef ctx,
 		      JSValueRef val, JSValueRef * exception)
@@ -2014,7 +2126,7 @@ seed_value_to_object (JSContextRef ctx,
    */
 
   if (JSValueIsNull (ctx, val))
-    return 0;
+    return NULL;
   if (!seed_value_is_gobject (ctx, val))
     {
       seed_make_exception (ctx, exception, "ConversionError",
@@ -2024,11 +2136,24 @@ seed_value_to_object (JSContextRef ctx,
     }
 
   gobject = (GObject *) JSObjectGetPrivate ((JSObjectRef) val);
-  g_assert(G_IS_OBJECT(gobject));
+  g_assert (G_IS_OBJECT (gobject));
 
   return gobject;
 }
 
+/**
+ * seed_value_from_object:
+ * @ctx: A #SeedContext.
+ * @val: The #GObject to wrap.
+ * @exception: A reference to a #SeedValue in which to store any exceptions.
+ *             Pass %NULL to ignore exceptions.
+ *
+ * Wraps @val in a #SeedValue.
+ *
+ * Return value: A #SeedValue which wraps @val, or %NULL if an exception
+ *               is raised during the conversion.
+ *
+ */
 JSValueRef
 seed_value_from_object (JSContextRef ctx,
 			GObject * val, JSValueRef * exception)
@@ -2040,18 +2165,19 @@ seed_value_from_object (JSContextRef ctx,
 }
 
 gboolean
-seed_validate_enum (GIEnumInfo *info,
-		    long val)
+seed_validate_enum (GIEnumInfo * info, long val)
 {
   gint n, i;
+  GIValueInfo *value_info;
+  glong value;
 
   n = g_enum_info_get_n_values (info);
   for (i = 0; i < n; i++)
     {
-      GIValueInfo *value_info = g_enum_info_get_value (info, i);
-      glong value = g_value_info_get_value (value_info);
+      value_info = g_enum_info_get_value (info, i);
+      value = g_value_info_get_value (value_info);
 
-      g_base_info_unref ((GIBaseInfo *)value_info);
+      g_base_info_unref ((GIBaseInfo *) value_info);
       if (value == val)
 	return TRUE;
     }
@@ -2060,51 +2186,47 @@ seed_validate_enum (GIEnumInfo *info,
 }
 
 JSValueRef
-seed_value_from_time_t (JSContextRef ctx,
-			time_t time,
-			JSValueRef *exception)
+seed_value_from_time_t (JSContextRef ctx, time_t time, JSValueRef * exception)
 {
   JSValueRef args[1];
 
-  args[0] = seed_value_from_double (ctx, ((gdouble)time)*1000, exception);
-  return JSObjectMakeDate(ctx, 1, args, exception);
+  args[0] = seed_value_from_double (ctx, ((gdouble) time) * 1000, exception);
+  return JSObjectMakeDate (ctx, 1, args, exception);
 }
 
 time_t
 seed_value_to_time_t (JSContextRef ctx,
-		      JSValueRef value,
-		      JSValueRef *exception)
+		      JSValueRef value, JSValueRef * exception)
 {
+  JSValueRef get_time_method;
+  JSValueRef jstime;
+  gdouble time;
+
+
   if (JSValueIsNumber (ctx, value))
     {
       return (unsigned long) seed_value_to_long (ctx, value, exception);
     }
   else if (JSValueIsObject (ctx, value))
     {
-      JSValueRef get_time_method;
-      JSValueRef jstime;
-      gdouble time;
-
-      get_time_method = seed_object_get_property (ctx, (JSObjectRef)value,
+      get_time_method = seed_object_get_property (ctx, (JSObjectRef) value,
 						  "getTime");
-      if (JSValueIsNull(ctx, get_time_method) ||
-	  !JSValueIsObject(ctx, get_time_method))
+      if (JSValueIsNull (ctx, get_time_method) ||
+	  !JSValueIsObject (ctx, get_time_method))
 	{
 	  goto out;
 	}
       jstime = JSObjectCallAsFunction (ctx,
-				       (JSObjectRef)get_time_method,
-				       (JSObjectRef)value,
-				       0, NULL,
-				       exception);
+				       (JSObjectRef) get_time_method,
+				       (JSObjectRef) value,
+				       0, NULL, exception);
       time = seed_value_to_double (ctx, jstime, exception);
-      return (unsigned long)(time/1000);
+      return (unsigned long) (time / 1000);
     }
 
- out:
+out:
   seed_make_exception (ctx, exception,
 		       "TypeError",
 		       "Unable to convert JavaScript value to time_t");
   return 0;
 }
-
